
#include "libmaix.h"
#include "stdio.h"
// #include "global_config.h"

void test_maix()
{
    printf("libmaix test1\n");
}

